==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/stuf0204/DatumMetIndicator.java <==

package nl.egem.stuf.stuf0204;

import java.math.BigDecimal;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.sector.bg._0204.GeboortedatumE;


/**
 * <p>Java class for DatumMetIndicator complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DatumMetIndicator">
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/StUF0204>Datum">
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *       &lt;attribute ref="{http://www.egem.nl/StUF/StUF0204}indOnvolledigeDatum"/>
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DatumMetIndicator", propOrder = {
    "value"
})
@XmlSeeAlso({
    DatumMetIndicatorKerngegeven.class,
    GeboortedatumE.class,
    nl.egem.stuf.sector.bg._0204.PRBFund.Ingangsdatum.class,
    nl.egem.stuf.sector.bg._0204.PRSKerngegevens.Geboortedatum.class,
    nl.egem.stuf.sector.bg._0204.NNPKerngegevens.DatumOprichtingNietNatuurlijkPersoon.class,
    nl.egem.stuf.sector.bg._0204.NNPFund.DatumOprichtingNietNatuurlijkPersoon.class,
    nl.egem.stuf.sector.bg._0204.PRBKerngegevens.Ingangsdatum.class,
    nl.egem.stuf.sector.bg._0204.PRSFund.DatumVerkrijgingVerblijfstitel.class,
    nl.egem.stuf.sector.bg._0204.PRSFund.DatumVerliesVerblijfstitel.class,
    nl.egem.stuf.sector.bg._0204.PRSPRSHUWRel.DatumSluiting.class,
    nl.egem.stuf.sector.bg._0204.WOZFund.PeildatumWaarde.class,
    nl.egem.stuf.sector.bg._0204.KDOZKRRel.IngangsDatumZakelijkRecht.class
})
public class DatumMetIndicator {

    @XmlValue
    protected BigDecimal value;
    @XmlAttribute(name = "indOnvolledigeDatum", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected IndOnvolledigeDatum indOnvolledigeDatum;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;
    @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Boolean exact;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setValue(BigDecimal value) {
        this.value = value;
    }

    /**
     * Gets the value of the indOnvolledigeDatum property.
     * 
     * @return
     *     possible object is
     *     {@link IndOnvolledigeDatum }
     *     
     */
    public IndOnvolledigeDatum getIndOnvolledigeDatum() {
        if (indOnvolledigeDatum == null) {
            return IndOnvolledigeDatum.V;
        } else {
            return indOnvolledigeDatum;
        }
    }

    /**
     * Sets the value of the indOnvolledigeDatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link IndOnvolledigeDatum }
     *     
     */
    public void setIndOnvolledigeDatum(IndOnvolledigeDatum value) {
        this.indOnvolledigeDatum = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

    /**
     * Gets the value of the exact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExact() {
        if (exact == null) {
            return true;
        } else {
            return exact;
        }
    }

    /**
     * Sets the value of the exact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExact(Boolean value) {
        this.exact = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/DatumMetIndicator.java <==

package nl.egem.stuf.stuf0204;

import java.math.BigDecimal;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.sector.bg._0204.GeboortedatumE;


/**
 * <p>Java class for DatumMetIndicator complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DatumMetIndicator"&gt;
 *   &lt;simpleContent&gt;
 *     &lt;extension base="&lt;http://www.egem.nl/StUF/StUF0204&gt;Datum"&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *       &lt;attribute ref="{http://www.egem.nl/StUF/StUF0204}indOnvolledigeDatum"/&gt;
 *     &lt;/extension&gt;
 *   &lt;/simpleContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DatumMetIndicator", propOrder = {
    "value"
})
@XmlSeeAlso({
    DatumMetIndicatorKerngegeven.class,
    nl.egem.stuf.sector.bg._0204.KDOZKRRel.IngangsDatumZakelijkRecht.class,
    nl.egem.stuf.sector.bg._0204.NNPKerngegevens.DatumOprichtingNietNatuurlijkPersoon.class,
    nl.egem.stuf.sector.bg._0204.NNPFund.DatumOprichtingNietNatuurlijkPersoon.class,
    nl.egem.stuf.sector.bg._0204.PRBFund.Ingangsdatum.class,
    nl.egem.stuf.sector.bg._0204.PRBKerngegevens.Ingangsdatum.class,
    nl.egem.stuf.sector.bg._0204.PRSKerngegevens.Geboortedatum.class,
    nl.egem.stuf.sector.bg._0204.PRSFund.DatumVerkrijgingVerblijfstitel.class,
    nl.egem.stuf.sector.bg._0204.PRSFund.DatumVerliesVerblijfstitel.class,
    nl.egem.stuf.sector.bg._0204.PRSPRSHUWRel.DatumSluiting.class,
    nl.egem.stuf.sector.bg._0204.WOZFund.PeildatumWaarde.class,
    GeboortedatumE.class
})
public class DatumMetIndicator {

    @XmlValue
    protected BigDecimal value;
    @XmlAttribute(name = "indOnvolledigeDatum", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected IndOnvolledigeDatum indOnvolledigeDatum;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;
    @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Boolean exact;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setValue(BigDecimal value) {
        this.value = value;
    }

    /**
     * Gets the value of the indOnvolledigeDatum property.
     * 
     * @return
     *     possible object is
     *     {@link IndOnvolledigeDatum }
     *     
     */
    public IndOnvolledigeDatum getIndOnvolledigeDatum() {
        if (indOnvolledigeDatum == null) {
            return IndOnvolledigeDatum.V;
        } else {
            return indOnvolledigeDatum;
        }
    }

    /**
     * Sets the value of the indOnvolledigeDatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link IndOnvolledigeDatum }
     *     
     */
    public void setIndOnvolledigeDatum(IndOnvolledigeDatum value) {
        this.indOnvolledigeDatum = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

    /**
     * Gets the value of the exact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExact() {
        if (exact == null) {
            return true;
        } else {
            return exact;
        }
    }

    /**
     * Sets the value of the exact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExact(Boolean value) {
        this.exact = value;
    }

}
